style "windowbg"
{
   engine "pixmap"
   {
        image
        {
                function = FLAT_BOX
				recolorable		= TRUE
                file = "WindowBg/6.jpg"
                border = {0, 0, 0, 0}
				stretch = FALSE
         }
   
     }

 }

class "GtkWindow" style "windowbg"
