/* dark colormap */

@define-color theme_base_color #060A0F;
@define-color theme_text_color #6EBEFE;
@define-color theme_bg_color #232323;
@define-color theme_fg_color @theme_text_color;
@define-color selected_bg_color #0D377C;
@define-color selected_fg_color #ffffff;
@define-color theme_selected_bg_color @selected_bg_color;

@define-color menu_bg_color #555753;
@define-color menu_fg_color @theme_text_color;

@define-color menu_combobox_border @theme_selected_bg_color;
@define-color menu_separator mix (@theme_bg_color, @menu_bg_color, 0.90);

@define-color theme_tooltip_bg_color #000000;
@define-color theme_tooltip_fg_color #eeeeee;


@define-color button_border #24282a;

@define-color button_raised_linked_shadow alpha(#000000, 0.14);


@define-color insensitive_bg_color alpha(#0b0b0d, 0.0);
@define-color insensitive_fg_color alpha(#717171, 0.50);
@define-color insensitive_border_color alpha(#717171, 0.50);

@define-color inactive_frame_color shade (@theme_bg_color, 0.8);

@define-color notebook_border @button_border;


@define-color switch_slider_color #111113;
@define-color switch_slider_border #a5b8cc;

@define-color highlighted_border @button_border;
@define-color internal_element_color #888a85;
@define-color internal_element_prelight #333333;

@define-color progressbar_background #030303;
@define-color progressbar_border #3D3D3D;

@define-color progressbar_background_a #00455F;
@define-color progressbar_background_b #0082B2;
@define-color progressbar_pattern #000000;

@define-color entry_text_color #6EBEFE;
@define-color entry_background_a #848684;
@define-color entry_background_b #babcba;
@define-color entry_background_c #e7e8e7;
@define-color entry_background_d #f3f3f3;

@define-color frame_color #707070;


@define-color toolbar_gradient_base #484848;
@define-color toolbar_gradient_step1 #383838;
@define-color toolbar_gradient_step2 #2F2F2F;
@define-color toolbar_gradient_final #000000;

@define-color toolbar_active_button_color #06439C;
@define-color toolbar_border_top #050505;
@define-color toolbar_border_bottom #595959;

@define-color primary_toolbar_entry_bg #060A0F;
@define-color primary_toolbar_entry_fg @theme_text_color;



@define-color menu_controls_color #aaa8ac;


@define-color trough_bg_color_a #252525;
@define-color trough_bg_color_b #41433f;




/* FIXME: needs dark colors from here */
@define-color link_color #4a90d9;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);

@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #ccc;
@define-color os_chrome_selected_bg_color #333;
@define-color os_chrome_selected_fg_color white;

@define-color chrome_bg_color #1e1a17;
@define-color chrome_fg_color #fff;

@define-color scale_progress_fill #2c85e2;
@define-color scale_progress_border #1864b2;
@define-color scale_progress_border_b #3e90e5;

@define-color wm_title_highlight #111111;
@define-color wm_shadow #000000;

@define-color osd_text_shadow #000000;
@define-color window_frame #7C7C7C;
@define-color window_frame_inactive #3E3E3E;


@import url("gtk-widgets.css");
@import url("gnome-applications.css");
@import url("gtk-widgets-overrides.css");


